@@ -1,4 +1,5 @@
 from functools import partial
+from pathlib import Path
 from transformers import TrainerCallback
 
 from maminbot.generation_utils import generate
@@ -9,7 +10,7 @@ class TextGenerationCallback(TrainerCallback):
     sense of different checkpoints.
     """
 
-    def __init__(self, prompts, path, **generate_kwargs):
+    def __init__(self, prompts, out_dir, **generate_kwargs):
         """
         Parameters
         ----------
@@ -18,14 +19,16 @@ class TextGenerationCallback(TrainerCallback):
         generate_kwargs: any
         """
         self.prompts = list(prompts)
-        self.path = path
+        self.out_dir = out_dir
+        self.out_path = Path(out_dir)/'generated_text_samples.txt'
         self.generate_kwargs = generate_kwargs
-        self.generate_fn = partial(generate, path=path, **generate_kwargs)
+        self.generate_fn = partial(generate, out_dir=out_dir,
+                                   **generate_kwargs)
         self.sep = '\n' + '=' * 79 + '\n'
         self.header_fmt = '{sep}GLOBAL STEP {global_step}{sep}'
 
     def on_evaluate(self, args, state, control, **kwargs):
-        with open(self.path, 'a') as f:
+        with open(self.out_path, 'a') as f:
             f.write(self.header_fmt.format(sep=self.sep,
                                            global_step=state.global_step))
         for prompt in self.prompts:
